==> prd_backup_01_06_23.zip: prd/resources/views/admin/aircraftapi/aircraft_list.blade.php <==
@extends('admin.layouts.master')
@section('content')
<style>
  table{
  /* margin: 0 auto; */
  clear: both;
  border-collapse: collapse;
  /* table-layout: fixed;  */
  word-wrap:break-word; 
  display: inline-table;
} 
button.search_button {
    size: 28px;
    width: 30px;
    height: 24px;
}
.d-flex.justify-content-center {
    margin-top: 15px;
}
  </style>
<head>
  <meta name="csrf-token" content="{{ csrf_token() }}">
</head>
<div class="breadcrumb-area">
  <div class="container-fluid">
    <nav aria-label="breadcrumb">
      <ol class="breadcrumb">
        <li class="breadcrumb-item"><a href="#">Activity</a></li>
        </li>
      </ol>
    </nav>
  </div>
</div>

<div class="container-fluid">
  <div class="row">
    <div class="col-12">
      <div class="product-list--area bg-boxshadow">
        <div class="row">
          <div class="col-lg-12">
            <div class="ibox">
              <div class="ibox-content">
              {{ Form::open(array('route' => ['aircraftview'], 'id' => 'myForm')) }}
                <table id="my_table3" class="display table table-stripped toggle-arrow-tiny dataTable no-footer" data-page-size="15">
                 
                    <thead>
                      <tr>
                    <th>
                    <?php $entries = [800,50,10,25,100,200,300,500,900,1200]; ?>
                          <p>Show
                          <select name="no_of_entries" onchange="filtreresult()" id="no_of_entries">
                            @foreach($entries as $entrie)
                              @if(isset($request['no_of_entries']))
                                @if($request['no_of_entries'] == $entrie) 
                                  <option value='<?php echo $entrie; ?>' selected><?php echo $entrie; ?></option>
                                @else
                                  <option value='<?php echo $entrie; ?>'><?php echo $entrie; ?></option>
                                @endif  
                              @else
                              <option value="<?php echo $entrie; ?>"> <?php echo $entrie; ?></option>
                              @endif
                            @endforeach
                          </select>  
                          </th>
                          Entries</p>
                          
                                <th data-orderable="false"></th>
                                <th data-orderable="false"></th>
                                <th data-orderable="false"></th>
                                <th class="filtres">
                          <th class="searh_bar">
                                @if(isset($request['search']))
                                <input class="search_bar" type="text" placeholder="Search.." name="search" value="<?php echo $request['search']; ?>">
                                @else
                                <input class="search_bar" type="text" placeholder="Search.." name="search">
                                @endif
                                <button onchange="filtreresult()" class="search_button" type="submit"><i class="fa fa-search"></i></button>
                                <input type="hidden" id="page" name="page" >  
                              </th>
</tr>
                        <tr>
                        <th>id</th>
                        <th class="cu">Type/Action</th>
                        <th class="cu">Ac/Username</th>
                        <th class="cu">Variant/Passwd</th>
                        <th class="cu">Cat</th>
                        <th class="cu">Check</th>
                        </tr>
                        <tr>
                        
                        @foreach($airCraft as $airCraf)
                        
                        <td>{{$airCraf->id}}</td>
                        <td>{{$airCraf->fleetACCategory}}</td>
                        <td>{{$airCraf->Manufacturer}}</td>
                        <td>{{$airCraf->fleetAC_Type}}</td>
                        <td>{{$airCraf->priceCategory}}</td>
                        <td>{{$airCraf->checkTrial}}</td>
                        </tr>
                        @endforeach
                        
                  </thead>
                  
                </table>
                {{ Form::close() }}  
                <div class="d-flex justify-content-center">
                        {{ $airCraft->links('admin.pagination') }} 
                
                      </div>
              </div>    
              </div>
            </div>
        </div>
    </div>
    
</div>
</div>
</div> 

<script>

function filtreresult() {

    document.getElementById("myForm").submit();

    $.ajax({ 
        headers: {
            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
        },
         url: "{{ route('aircraftview') }}",
         body: formData,
         type: 'post',
         success: function(result){
            console.log(result)
         }
        });
}
  </script>
@endsection

==> prd_backup_23_03_23.zip: prd/resources/views/admin/aircraftapi/aircraft_list.blade.php <==
@extends('admin.layouts.master')
@section('content')
<style>
  table{
  /* margin: 0 auto; */
  clear: both;
  border-collapse: collapse;
  /* table-layout: fixed;  */
  word-wrap:break-word; 
  display: inline-table;
} 
  </style>
<head>
  <meta name="csrf-token" content="{{ csrf_token() }}">
</head>
<div class="breadcrumb-area">
  <div class="container-fluid">
    <nav aria-label="breadcrumb">
      <ol class="breadcrumb">
        <li class="breadcrumb-item"><a href="#">Activity</a></li>
        </li>
      </ol>
    </nav>
  </div>
</div>

<div class="container-fluid">
  <div class="row">
    <div class="col-12">
      <div class="product-list--area bg-boxshadow">
        <div class="row">
          <div class="col-lg-12">
            <div class="ibox">
              <div class="ibox-content">
                <table id="my_table3" class="display table table-stripped toggle-arrow-tiny dataTable no-footer" data-page-size="15">
                  
                    <thead>
                        <tr>
                        <th>id</th>
                        <th class="cu">Aircraft Name</th>
                        </tr>
                        <tr>
                        @foreach($airCraft as $airCraf)

                        <td>{{$airCraf['id']}}</td>
                        <td>{{$airCraf['aircraft']}}</td>
                        </tr>
                        @endforeach
                        
                  </thead>
                </table>
              </div>    
              </div>
            </div>
        </div>
    </div>
</div>
</div>
</div> 
@endsection
